@@ -38,7 +38,7 @@ def _map_sql(self, expression):
         return f"MAP({self.sql(keys)}, {self.sql(values)})"
 
     args = []
-    for key, value in zip(keys.args["expressions"], values.args["expressions"]):
+    for key, value in zip(keys.expressions, values.expressions):
         args.append(self.sql(key))
         args.append(self.sql(value))
     return f"MAP({csv(*args)})"
@@ -52,15 +52,18 @@ def _array_sort(self, expression):
 
 def _properties_sql(self, expression):
     expression = expression.copy()
-    properties = expression.args["expressions"]
+    properties = expression.expressions
 
+    using = ""
     stored_as = ""
     partitioned_by = ""
 
     for p in properties:
-        if p.text("this").upper() == c.FORMAT:
+        if p.name.upper() == c.TABLE_FORMAT:
+            using = p
+        elif p.name.upper() == c.FILE_FORMAT:
             stored_as = p
-        if isinstance(p.args["value"], exp.Schema):
+        elif isinstance(p.args["value"], exp.Schema):
             partitioned_by = p
 
     if partitioned_by:
@@ -68,11 +71,14 @@ def _properties_sql(self, expression):
         partitioned_by = self.seg(
             f"PARTITIONED BY {self.sql(partitioned_by.args['value'])}"
         )
+    if using:
+        properties.remove(using)
+        using = self.seg(f"USING {using.text('value').upper()}")
     if stored_as:
         properties.remove(stored_as)
         stored_as = self.seg(f"STORED AS {stored_as.text('value').upper()}")
 
-    return f"{partitioned_by}{stored_as}{self.properties('TBLPROPERTIES', expression)}"
+    return f"{using}{partitioned_by}{stored_as}{self.properties('TBLPROPERTIES', expression)}"
 
 
 def _property_sql(self, expression):
@@ -108,19 +114,19 @@ def _time_to_str(self, expression):
 
 
 def _unnest_to_explode_sql(self, expression):
-    if isinstance(expression.this, exp.Unnest):
-        unnest = expression.this
+    unnest = expression.this
+    if isinstance(unnest, exp.Unnest):
+        alias = unnest.args.get("alias")
         udtf = exp.Posexplode if unnest.args.get("ordinality") else exp.Explode
         return "".join(
             self.sql(
                 exp.Lateral(
                     this=udtf(this=expression),
-                    table=unnest.args.get("table"),
-                    columns=[column],
+                    alias=exp.TableAlias(this=alias.this, columns=[column]),
                 )
             )
             for expression, column in zip(
-                unnest.args["expressions"], unnest.args.get("columns", [])
+                unnest.expressions, alias.columns if alias else []
             )
         )
     return self.join_sql(expression)
