@@ -7,6 +7,7 @@ from sqlglot.dialects import Dialect
 from sqlglot.executor.context import Context
 from sqlglot.executor.env import ENV
 from sqlglot.executor.table import Table
+from sqlglot.generator import Generator
 from sqlglot.helper import csv_reader
 
 
@@ -78,8 +79,11 @@ class PythonExecutor:
         return Table(expression.alias_or_name for expression in expressions)
 
     def scan(self, step, context):
-        if isinstance(step, planner.Scan):
-            source = step.source.this.name or step.source.alias
+        if hasattr(step, "source"):
+            source = step.source
+
+            if isinstance(source, exp.Expression):
+                source = source.this.name or source.alias
         else:
             source = step.name
         condition = self.generate(step.condition)
@@ -234,7 +238,7 @@ class PythonExecutor:
         return table
 
     def aggregate(self, step, context):
-        source = list(context.tables)[0]
+        source = step.source
         group_by = self.generate_tuple(step.group)
         aggregations = self.generate_tuple(step.aggregations)
         operands = self.generate_tuple(step.operands)
@@ -275,7 +279,7 @@ class PythonExecutor:
             group = key
             start = end - 2
 
-        return self.context({step.name: table})
+        return self.scan(step, self.context({source: table}))
 
     def sort(self, step, context):
         table = list(context.tables)[0]
@@ -284,51 +288,58 @@ class PythonExecutor:
         return self.scan(step, context)
 
 
+# pylint: disable=no-member
+def _cast_py(self, expression):
+    to = expression.args["to"].this
+    this = self.sql(expression, "this")
+
+    if to == exp.DataType.Type.DATE:
+        return f"datetime.date.fromisoformat({this})"
+    if to == exp.DataType.Type.TEXT:
+        return f"str({this})"
+    raise NotImplementedError
+
+
+def _column_py(self, expression):
+    table = self.sql(expression, "table")
+    this = self.sql(expression, "this")
+    return f"scope[{table}][{this}]"
+
+
+def _interval_py(self, expression):
+    this = self.sql(expression, "this")
+    unit = expression.text("unit").upper()
+    if unit == "DAY":
+        return f"datetime.timedelta(days=float({this}))"
+    raise NotImplementedError
+
+
+def _like_py(self, expression):
+    this = self.sql(expression, "this")
+    expression = self.sql(expression, "expression")
+    return f"""re.match({expression}.replace("_", ".").replace("%", ".*"), {this})"""
+
+
+def _ordered_py(self, expression):
+    this = self.sql(expression, "this")
+    desc = expression.args.get("desc")
+    return f"desc({this})" if desc else this
+
+
 class Python(Dialect):
-    # pylint: disable=no-member
-    def _cast_py(self, expression):
-        to = expression.args["to"].this
-        this = self.sql(expression, "this")
-
-        if to == exp.DataType.Type.DATE:
-            return f"datetime.date.fromisoformat({this})"
-        if to == exp.DataType.Type.TEXT:
-            return f"str({this})"
-        raise NotImplementedError
-
-    def _column_py(self, expression):
-        table = self.sql(expression, "table")
-        this = self.sql(expression, "this")
-        return f"scope[{table}][{this}]"
-
-    def _interval_py(self, expression):
-        this = self.sql(expression, "this")
-        unit = expression.text("unit").upper()
-        if unit == "DAY":
-            return f"datetime.timedelta(days=float({this}))"
-        raise NotImplementedError
-
-    def _like_py(self, expression):
-        this = self.sql(expression, "this")
-        expression = self.sql(expression, "expression")
-        return (
-            f"""re.match({expression}.replace("_", ".").replace("%", ".*"), {this})"""
-        )
-
-    def _ordered_py(self, expression):
-        this = self.sql(expression, "this")
-        desc = expression.args.get("desc")
-        return f"desc({this})" if desc else this
-
-    transforms = {
-        exp.Alias: lambda self, e: self.sql(e.this),
-        exp.And: lambda self, e: self.binary(e, "and"),
-        exp.Cast: _cast_py,
-        exp.Column: _column_py,
-        exp.EQ: lambda self, e: self.binary(e, "=="),
-        exp.Interval: _interval_py,
-        exp.Like: _like_py,
-        exp.Or: lambda self, e: self.binary(e, "or"),
-        exp.Ordered: _ordered_py,
-        exp.Star: lambda *_: "1",
-    }
+    class Generator(Generator):
+        TRANSFORMS = {
+            exp.Alias: lambda self, e: self.sql(e.this),
+            exp.And: lambda self, e: self.binary(e, "and"),
+            exp.Cast: _cast_py,
+            exp.Column: _column_py,
+            exp.EQ: lambda self, e: self.binary(e, "=="),
+            exp.Interval: _interval_py,
+            exp.Is: lambda self, e: self.binary(e, "is"),
+            exp.Like: _like_py,
+            exp.Not: lambda self, e: f"not {self.sql(e.this)}",
+            exp.Null: lambda *_: "None",
+            exp.Or: lambda self, e: self.binary(e, "or"),
+            exp.Ordered: _ordered_py,
+            exp.Star: lambda *_: "1",
+        }
