@@ -56,7 +56,14 @@ def _pop_table_column_aliases(derived_tables):
 
 
 def _expand_using(scope, schema):
-    for join in scope.expression.find_all(exp.Join):
+    joins = list(scope.expression.find_all(exp.Join))
+    names = {join.this.alias for join in joins}
+    ordered = [key for key in scope.selected_sources if key not in names]
+
+    # Mapping of automatically joined column names to source names
+    column_tables = {}
+
+    for join in joins:
         using = join.args.get("using")
 
         if not using:
@@ -64,14 +71,16 @@ def _expand_using(scope, schema):
 
         join_table = join.this.alias_or_name
 
-        source_columns = {
-            k: _get_source_columns(k, scope.sources, schema)
-            for k in scope.selected_sources
-            if join_table != k
-        }
-        join_columns = _get_source_columns(join_table, scope.sources, schema)
+        columns = {}
 
-        columns = _get_unambiguous_columns(source_columns)
+        for k in scope.selected_sources:
+            if k in ordered:
+                for column in _get_source_columns(k, scope.sources, schema):
+                    if column not in columns:
+                        columns[column] = k
+
+        ordered.append(join_table)
+        join_columns = _get_source_columns(join_table, scope.sources, schema)
         conditions = []
 
         for identifier in using:
@@ -90,13 +99,34 @@ def _expand_using(scope, schema):
                 )
             )
 
+            tables = column_tables.setdefault(identifier, [])
+            if table not in tables:
+                tables.append(table)
+            if join_table not in tables:
+                tables.append(join_table)
+
         join.args.pop("using")
         join.set("on", exp.and_(*conditions))
 
+    if column_tables:
+        for column in scope.columns:
+            if not column.table and column.name in column_tables:
+                tables = column_tables[column.name]
+                coalesce = [exp.column(column.name, table=table) for table in tables]
+                replacement = exp.Coalesce(this=coalesce[0], expressions=coalesce[1:])
+
+                # Ensure selects keep their output name
+                if isinstance(column.parent, exp.Select):
+                    replacement = exp.alias_(replacement, alias=column.name)
+
+                scope.replace(column, replacement)
+
 
 def _qualify_columns(scope, schema):
     """Disambiguate columns, ensuring each column specifies a source"""
-    unambiguous_columns = None  # lazily loaded
+    # lazily loaded
+    unambiguous_columns = None
+    all_columns = None
 
     for column in scope.columns:
         column_table = column.table
@@ -118,10 +148,19 @@ def _qualify_columns(scope, schema):
                 }
 
                 unambiguous_columns = _get_unambiguous_columns(source_columns)
+                all_columns = set(
+                    column for columns in source_columns.values() for column in columns
+                )
 
             column_table = unambiguous_columns.get(column_name)
-            if not column_table and not scope.is_subquery:
-                raise OptimizeError(f"Ambiguous column: {column_name}")
+
+            if not scope.is_subquery:
+                if column_name not in all_columns:
+                    raise OptimizeError(f"Unknown column: {column_name}")
+
+                if not column_table:
+                    raise OptimizeError(f"Ambiguous column: {column_name}")
+
             column.set("table", exp.to_identifier(column_table))
 
 
