@@ -52,14 +52,15 @@ class Scope:
         self.scope_type = scope_type
         self.subquery_scopes = []
         self.union = None
+        self._clear_cache()
 
+    def _clear_cache(self):
         self._collected = False
         self._raw_columns = None
         self._derived_tables = None
         self._tables = None
         self._ctes = None
         self._subqueries = None
-
         self._selected_sources = None
         self._columns = None
         self._external_columns = None
@@ -106,6 +107,19 @@ class Scope:
         if not self._collected:
             self._collect()
 
+    def replace(self, old, new):
+        """
+        Replace `old` with `new`.
+
+        This can be used instead of `exp.Expression.replace` to ensure the `Scope` is kept up-to-date.
+
+        Args:
+            old (exp.Expression): old node
+            new (exp.Expression): new node
+        """
+        old.replace(new)
+        self._clear_cache()
+
     @property
     def tables(self):
         """
@@ -186,7 +200,9 @@ class Scope:
                 for c in columns + external_columns
                 if c.table
                 or not (
-                    c.find_ancestor(exp.Group, exp.Order) and c.name in aliased_outputs
+                    # In some dialects, these clauses can reference output columns
+                    c.find_ancestor(exp.Group, exp.Order, exp.Qualify)
+                    and c.name in aliased_outputs
                 )
             ]
         return self._columns
