@@ -94,7 +94,6 @@ class Parser:
         TokenType.ORDINALITY,
         TokenType.PERCENT,
         TokenType.PRECEDING,
-        TokenType.QUALIFY,
         TokenType.RANGE,
         TokenType.ROWS,
         TokenType.SCHEMA_COMMENT,
@@ -216,6 +215,16 @@ class Parser:
         "JOIN_TYPE": "_parse_join_side_and_kind",
     }
 
+    STATEMENT_PARSERS = {
+        TokenType.CREATE: "_parse_create",
+        TokenType.DROP: "_parse_drop",
+        TokenType.INSERT: "_parse_insert",
+        TokenType.UPDATE: "_parse_update",
+        TokenType.DELETE: "_parse_delete",
+        TokenType.CACHE: "_parse_cache",
+        TokenType.UNCACHE: "_parse_uncache",
+    }
+
     CREATABLES = {TokenType.TABLE, TokenType.VIEW, TokenType.FUNCTION}
 
     STRICT_CAST = True
@@ -396,26 +405,8 @@ class Parser:
         if self._curr is None:
             return None
 
-        if self._match(TokenType.CREATE):
-            return self._parse_create()
-
-        if self._match(TokenType.DROP):
-            return self._parse_drop()
-
-        if self._match(TokenType.INSERT):
-            return self._parse_insert()
-
-        if self._match(TokenType.UPDATE):
-            return self._parse_update()
-
-        if self._match(TokenType.DELETE):
-            return self._parse_delete()
-
-        if self._match(TokenType.CACHE):
-            return self._parse_cache()
-
-        if self._match(TokenType.UNCACHE):
-            return self._parse_uncache()
+        if self._match_set(self.STATEMENT_PARSERS):
+            return getattr(self, self.STATEMENT_PARSERS[self._prev.token_type])()
 
         if self._match_set(Tokenizer.COMMANDS):
             return self.expression(
@@ -817,11 +808,11 @@ class Parser:
                     "laterals": self._parse_laterals(),
                     "joins": self._parse_joins(),
                     "where": self._parse_where(),
-                    "window": self._match(TokenType.WINDOW)
-                    and self._parse_window(self._parse_id_var(), alias=True),
                     "group": self._parse_group(),
                     "having": self._parse_having(),
                     "qualify": self._parse_qualify(),
+                    "window": self._match(TokenType.WINDOW)
+                    and self._parse_window(self._parse_id_var(), alias=True),
                     "order": self._parse_order(),
                     "limit": limit or self._parse_limit(),
                     "offset": self._parse_offset(),
@@ -1265,7 +1256,14 @@ class Parser:
 
         while self._match_set(self.COLUMN_OPERATORS):
             colon = self._prev.token_type == TokenType.COLON
-            field = self._parse_star() or self._parse_id_var()
+            field = self._parse_star() or self._parse_function() or self._parse_id_var()
+
+            if isinstance(field, exp.Func):
+                # bigquery allows function calls like x.y.count(...)
+                # SAFE.SUBSTR(...)
+                # https://cloud.google.com/bigquery/docs/reference/standard-sql/functions-reference#function_call_rules
+                this = self._replace_columns_with_dots(this)
+
             if colon:
                 this = self.expression(
                     exp.Bracket,
@@ -1764,3 +1762,18 @@ class Parser:
                 self.raise_error("Expecting BY")
             return True
         return False
+
+    def _replace_columns_with_dots(self, this):
+        if isinstance(this, exp.Dot):
+            exp.replace_children(this, self._replace_columns_with_dots)
+        elif isinstance(this, exp.Column):
+            exp.replace_children(this, self._replace_columns_with_dots)
+            table = this.args.get("table")
+            this = (
+                self.expression(exp.Dot, this=table, expression=this.this)
+                if table
+                else self.expression(exp.Var, this=this.name)
+            )
+        elif isinstance(this, exp.Identifier):
+            this = self.expression(exp.Var, this=this.name)
+        return this
